@@ -9,5 +9,5 @@ The package containing utilities to develop Web3-based projects
 
 from .abc import Defi
 from .tools import validate_token, load_contracts, validate_network, encode_to_bytes32
-from .types import ContractMap
+from .types import ContractMap, Token
 from .exceptions import InvalidToken, InvalidToken, InvalidRoute
